const fs = require('fs')
const path = require('path')
const extract = require('extract-zip')
const chalk = require('chalk')
const Downloader = require('nodejs-file-downloader')

const fileName = 'template.zip'
const tempFileName = `_${fileName}`

function logS(message) {
  console.log(chalk.green(message))
}

function logE(message) {
  console.log(chalk.red(message))
}

exports.initDir = function(dir) {
  if (!!!dir || dir === '.') return

  const temp = path.join(process.cwd(), dir)
  if (!fs.existsSync(temp)) {
    fs.mkdirSync(temp)
    logS('> react cli mkdir success')
  }
}

exports.downloadTemplate = async function(url, dir) {
  logS('> react cli template downloading...')
  await new Downloader({
    url,
    directory: path.join(process.cwd(), dir),
    onBeforeSave:()=>{ return tempFileName }            
  }).download()
  logS('> react cli download template completed')
}

exports.unzipTemplate = async function(dir) {
  const destFile = path.join(process.cwd(), dir, tempFileName)
  const destPath = path.join(process.cwd(), dir)
  try {
    await extract(destFile, { dir: destPath })
    fs.rmSync(destFile)
    logS('> react cli create template finish')
  } catch (err) {
    logE('> react cli unzip template error', err)
  }
}